**********************************************************
* Introduzione all'analisi dei dati longitudinali
* CAP 2:	LA PREPARAZIONE DEI DATI 
**********************************************************
* questa sintassi: 
* datamanage.do
* ALCUNI PASSI FONDAMENTALI PER GESTIRE I DATI*/
* commandi: COLLAPSE, MERGE, EXPAND, RESHAPE  
* VERSIONE: AGOSTO 2013
**********************************************************

*version 12.1 
capture log close
clear
*set more off
set logtype text
global dm F:\longi\data

***************************************/
/* LA STRUTTURA DEI DATI LONGITUDINALI E LA LORO GESTIONE  
/**************************************/
* Creamo dei dati artificiali*/

/* DATASET degli EPISODI (SPELL)*/
input id hid status ts tf 
101	20	0	1	6
101	20	1	6	21
101	20	2	21	23
101	20	1	23	40
102	20	0	1	45	
201	30	0	1	2
201	30	2	2	5
201	30	1	5	20
201	30	1	20	45
321	66	1	1	35
321	66	0	35	45
end
save $dm\spell.dta, replace
clear

/*  DATASET INDIVIDUALE*/
input id hid sex	educ	birthy	birthm	tbkid	
101	20	1	3	1955	2	19
102	20	0	2	1960	11	21
201	30	0	2	1945	1	-99
321	66	1	1	1970	7	37
end
save $dm\ind.dta, replace
clear 

/* di FAMIGLIA/ HOUSEHOLD */
input hid hhink nkids
20	3000	3
30	4500	0
66	2000	1
end 
sort hid
save $dm\hh.dta, replace
clear


/**************************/
/* L'ORGANIZAZIONE DEI DATI : SPELL, LONG and WIDE*/
/**************************/
/*  dal SPELL al LONG*/
use $dm\spell.dta, clear
* attenzione sulla codifica del TS !
gen dur=tf-ts
expand dur
sort id ts
*browse
by id: gen seqvar=_n
lab var seqvar "spell month identifier, by subject"
gen ts_split=seqvar 
gen tf_split=seqvar+1
save $dm\long.dta, replace
* NOTA: le cose diventono piu' complesse se l'asse del tempo non parte da 1


/* da LONG a WIDE*/
keep id status seqvar
reshape wide status, i(id) j(seqvar)
save $dm\wide.dta, replace
*browse

/* e torniamo al LONG */
reshape long status, i(id) j(seqvar)


***************************************/
/*   AGGERGARE e "MERGE"ARE i dati*/
***************************************/
/* Vogliamo sapere quanto tempo della carriera osservata*/
/* gli individui passano in STATUS 1 (essere occupato, per esempio)*/
/* e quanti episodi di occupazione hanno avuto*/
/**************************************/

use $dm\spell.dta, clear
gen dur=tf-ts
gen dur_empl=0
replace dur_empl=dur if status==1
tab dur_empl
gen nr_empl=0
replace nr_empl=1 if status==1
collapse (sum)dur_empl nr_empl, by (id)
tab id
tab dur_empl
tab nr_empl
sort id
save $dm\aggr.dta, replace
browse

/* la stessa informazion, senza modificare i dati, si puo' ottenere tramite egen*/ 
use $dm\spell.dta, clear
*help egen
sort id ts
gen dur=tf-ts
gen dur_empl=0
replace dur_empl=dur if status==1
replace dur_empl=dur_empl[_n-1]+dur_empl if id==id[_n-1]

tab dur_empl
gen nr_empl=0
replace nr_empl=1 if status==1
replace nr_empl=nr_empl[_n-1]+nr_empl if id==id[_n-1]
by id: egen m_demp=max(dur_empl) 
by id: egen m_nremp=max(nr_empl) 
browse


/**************************/
/* match	ONE-TO-ONE MATCH	  */
/**************************/
/* Per vedere differenze fra maschi e femmine dobbiamo agganciarge i dati individuali */
/* i dati devono essere ordinati!*/

use $dm\ind.dta, clear
sort id
save $dm\ind.dta, replace

use $dm\aggr.dta, replace
merge id using $dm\ind.dta 
save $dm\aggr.dta, replace
tab _merge
tab nr_empl sex
browse

***************************************/
/*  ONE-TO-MANY MATCH	*/
***************************************/
/* Aggiungiamo informazione individuale ai dati spell (episodi)*/
***************************************/

use $dm\spell.dta, clear
sort id
save $dm\spell.dta, replace
merge id using $dm\ind.dta 

*browse
drop _merge
save $dm\spell2.dta, replace


/* alla fine aggiungiamo anche l'info del livello famigliare*/
/* ordinare prima! questa volta su HID "household identifier"*/

use $dm\spell2.dta, clear
sort hid 
save $dm\spell2.dta, replace
merge hid using $dm\hh.dta
drop _merge
save $dm\spell2.dta, replace
browse

/**************************/
* EPISODE SPLITTING 
/**************************/

use $dm\spell2.dta, clear
* si studia la transizione in status==1 (avere un lavoro, per esempio)
sort id ts 
by id: gen nextstat=status[_n+1]
stset tf, origin(time ts) id(id) failure(nextstat==1) 
* il commando STSET dichiara la struttura dei dati per l'analisi degli eventi 
* help stset 
* !!! ATTENZIONE: per caso 321 non si osserva la _transizione_ allo status 1!!!  
* se e' censurata alla sinstra non si sa' da quanto tempo e' gia in status 1
* se invece incide col inizio dell'episodio (per esempio per costruzione i dati partono col primo impiego) 
* una soluzione facile e' inserire un mese di ricerca "artificiale" per tutti. 
browse 

stsplit split, after(tbkid) at(1)
sort id ts
* !!! ATTENTION !!!
* Stata crea  "split" soltanto se entra nell'analisi, cioe' dove _st=1
* le modifiche avengono per le "variabili di sistema" _st _d _t _t0 sulle quali si basa poi il calcolo 


use $dm\spell2.dta, clear
sort id ts 
by id: gen nextstat=status[_n+1]
stset tf, origin(time ts) id(id) failure(nextstat==1) exit(tf=.)
* 	in questo modo tutte le episodo vengono considerate e quindi splittato anche ID=101 
stsplit split, after(tbkid) at(1)

gen nascita=0
replace nascita=1 if tbkid<=tf & tbkid!=-99
save $dm\spell2_split.dta, replace

* possibilita' di arrivare ad un file mensilizzato 
*stsplit splitspell, every(1)  



/**************************/
* EFFETTI di DIVERSE forme di ORGANIZZARE dei DATI: 
* NESSUNO se e' fatto con la dovuta attenzione e in modo giusto
/**************************/

* dati SPELL  
use $dm\spell.dta, clear
sort id ts 
by id: gen nextstat=status[_n+1]
*oppure
*gen des=status[_n+1] if id==id[_n+1] 
stset tf, origin(time ts) id(id) failure(nextstat==1)  
stsum
* dati SPELL splittati 
use $dm\spell2_split.dta, clear
stset tf, origin(time ts) id(id) failure(nextstat==1)  
stsum

* dati LONG 
use $dm\long.dta, clear
sort id ts_split 
by id: gen nextstat=status[_n+1]
stset tf_split, origin(time ts_split) id(id) failure(nextstat==1) 
stsum
*ATTENZIONE!! vedi caso 321, 
* adesso si che osserviamo una transizione a status 1 anche se e' solo all'interno dello stesso episodio... 
gen failure=0
bys id: replace failure=1 if status[_n+1]==1 & status!=1
stset tf_split, origin(time ts_split) id(id) failure(failure) 
stsum

