**********************************************************
* Introduzione all'analisi dei dati longitudinali
* CAP 4:	ANALISI DEI DATI PANEL  
**********************************************************
* questa sintassi: 
* panel_models.do
* introduzione ai vari modelli 
* VERSIONE: AGOSTO 2013
*********************************************
** esempio tratto da Bruderl J. (2010). 
* http://www.ls3.soziologie.uni-muenchen.de/teach-materials/index.html


** MODELLI PANEL *** 
*version 12.1 
capture log close
set logtype text 
set dp comma 
global pa "F:\longi" 
use $pa\data\matrimonio.dta, clear
log using $pa\panel\panel_models.log, replace

 
di in red "Il matrimonio aumenta il reddito?" 

* Dichiarazione della struttura longitudinale e ordinamento cronologico osservazione
xtset ind tempo
sort ind tempo

*****************************************
* Descrittive
*****************************************

list ind tempo reddito matrimonio, separator(6)

* Descrizione dei dati
xtdes
xtsum reddito
xttab matrimonio
xtline reddito, overlay


******************************************
* Plot dei dati
******************************************
twoway  (scatter reddito tempo, ylabel(0(1000)5000, grid angle(0))       ///
                 ymtick(500(1000)4500, grid) c(L))                       ///
        (scatter reddito tempo if matrimonio==1, c(L)),                  ///
      legend(label(1 "pre-matrimonio") label(2 "post-matrimonio"))


******************************************
* Cross-sectional OLS: regressione at T=4
******************************************
regress  reddito matrimonio if tempo==4


******************************************
* Pooled OLS
******************************************
regress  reddito matrimonio                    // S.E. non tengono conto di struttura nested
regress  reddito matrimonio, vce(cluster ind)  // correzione per S.E.


* forte distorsione data da auto selezione 

******************************************
* Stimatore FD 
******************************************
sort ind tempo
generate  dreddito = reddito - L.reddito           // L. restituisce il valore o lo statpo della variabile a t-1
generate  dmatrimonio = matrimonio - L.matrimonio
regress   dreddito dmatrimonio, noconstant
regress   dreddito dmatrimonio, noconstant vce(cluster ind)  // correzione S.E.

*stima within, non efficiente, distorsione ridotta


twoway  (scatter dreddito dmatrimonio, jitter(2))                ///
        (lfit dreddito dmatrimonio, estopts(noconstant)),        ///
        legend(off) ylabel(-200(100)600, grid) xtitle(delta(matrimonio)) ytitle(delta(reddito))

		
* calcolo manuale dello stimatore DID, difference in differences
display (((4500-4000)+(3500-3000))/2)-(((2000-2000)+(1000-1000))/2)

*******************************************
* Stimatore FE
*******************************************
xtreg reddito matrimonio, fe                   
*stima within, efficiente. eterogeneit non osservata sotto controllo
		
* calcolo manuale dello stimatore DID, difference in differences
display (((4500-4000)+(3500-3000))/2)-(((2000-2000)+(1000-1000))/2)


*******************************************
*Logica del modello FE
*******************************************
**FE "trasformazioni a mano"
egen      mreddito = mean(reddito), by(ind)
egen      mmatrimonio = mean(matrimonio), by(ind)
generate  wreddito = reddito - mreddito
generate  wmatrimonio = matrimonio - mmatrimonio
regress   wreddito wmatrimonio


********************************************
* Stimatore equivalente: LSDV
********************************************
* Dummy Variable Regression(LSDV)

tabulate ind, gen(pers)
regress reddito matrimonio pers1-pers4, noconstant


*******************************************
* Random-Effects Regression
*******************************************
xtreg reddito matrimonio, theta re 

*utilizzo di una combinazione di varianza within (96%) e between. Stima convergente con risultati FE

* Hausman Test (1) stima RE e salvataggio risultati, 2) stima FE e salvataggio risultati 3) test chi^2)
xtreg reddito matrimonio, re
estimates store randeff
xtreg reddito matrimonio, fe
estimates store fixdeff
hausman fixdeff randeff, sigmamore

*l'impatto sostantivo della distorsione  ridotto, tuttavia le stime si discostano (statisticamente) in maniera significativa: 
*standpo al test, adrebbe adottata la specificazione FE




***********************************************************************************
*Caso di causalit inversa, impatto reale di x =0, aumento del reddito causa x=1 
***********************************************************************************

twoway (scatter reddito2 tempo, ylabel(0(1000)5000, grid) ymtick(500(1000)4500, grid) c(L))  ///
 (scatter reddito tempo if matrimonio==1, c(L)),                                            ///
 legend(label(1 "pre-matrimonio") label(2 "post-matrimonio"))  ytitle("Euro mensili")

**Modello FE
xtreg reddito2 matrimonio, fe
**FE non corregge la distorsione da causalit inversa


*Modello IV, Lag(matrimonio) usato come strumento 
xtivreg reddito2 (matrimonio=L.matrimonio), fe
**distorsione ridotta e tuttavia significativa

*Modello FD
sort ind tempo
generate  dreddito2 = reddito2 - L.reddito2
generate  dmatrimonio2 = matrimonio  - L.matrimonio
regress   dreddito2 dmatrimonio2, noconstant
**FD basandosi su differenze t / t-1 in questo caso corregge la distorsione da causalit inversa


*******************************************************************
* Effetti di periodo correlati ad x, impatto reale del matrimonio=0
*******************************************************************

twoway                                                                            ///
 (scatter reddito3 tempo, ylabel(0(1000)5000, grid) ymtick(500(1000)4500, grid) c(L)) ///
 (scatter reddito3 tempo if matrimonio==1, c(L)),                                           ///
 legend(label(1 "pre-matrimonio") label(2 "post-matrimonio")) ytitle("Euro mensili")
	
* FE Regression (within estimator)
xtreg reddito3 matrimonio, fe

**effetto da shock esogeno, non controllato dal FE

* Twoway FE-Model
tab tempo, gen(t)
xtreg reddito3 matrimonio t2-t6, fe
**effetto da shock esogeno controllato tramite dummy di tempo



 
