**********************************************************
* Introduzione all'analisi dei dati longitudinali
* CAP 5:	ANALISI DELLE SEQUENZE 
***********************************************************
* questa sintassi: 
* seq_sa_om.do
* descrizione delle sequenze individuali e  
* OMA: confronto pairwise 
* - tabelle 3 
* - figura  3 e 4 
* VERSIONE: AGOSTO 2013
***********************************************************
*version 12.1 
global sa F:\longi\
use $sa\data\carriereIT_lungo.dta, clear 
set dp comma 

***********************************************************
* Standardizzazione delle Sequenze a 5 anni di osservazione  
***********************************************************
bys id: gen nr=_n
keep if nr<=61
egen nrmax=max(nr), by(id)  
keep if nrmax==61 

* elimina il primo mese artificiale 
drop if nr==1 
replace time=time-1

* riduciamo lo State Space 
recode empstat 31 32 33=30 21 22=20
lab def empstat 30 "Inattivo" 20"Disoccupato" 13"Dip. temp. det." 11"Autonomo" 12"Dip. indet." , modify 

tab empstat


**************************
* Definizione delle Sequenze
**************************

sqset empstat id time

**********************
* COMPARAZIONE PAIRWISE
**********************

* ATTENZIONE ''! 
* ... questa parte richiede parecchio tempo per il calcolo ..
* si consiglia tintant di iniziare il lavor su un substample

*	default: indel = 1, subcost = 2
sqom, full 

sqclusterdat
clustermat wardslinkage SQdist, add
clustermat stop, variable(_clus_1_hgt) rule(calinski)
clustermat stop, variable(_clus_1_hgt) rule(duda)
cluster gen oma=groups(2/15)
sqclusterdat, return

/*
*	specificazione dei costi per sostituzione alternativa
*	1. costi basati sulle probabilita' di transizione fra i status osservate empiricamente nei dati
sqom, full subcost(meanprobdistance) 
sqclusterdat
clustermat wardslinkage SQdist, add
cluster gen omaew=groups(2/15)
sqclusterdat, return
*	2. matrice dei costi motivato "teoreticamente" 
# delimit ;
matrix scostw2 = 
(0,1,1.5,2,3
\1,0,1.5,2,3
\1.5,1.5,0,2,3
\2,2,2,0,2
\3,3,3,2,0);
# delimit cr
sqom, full subcost(scostw2) 
sqclusterdat
clustermat wardslinkage SQdist, add
cluster gen omatw=groups(2/15)
sqclusterdat, return
*/

* calcolo OM alternativo: 
*	OMAv for adjustment of duration in status, 
*	see: Halpin 2010


save $sa/data/clus, replace

** per non rifarlo o gni volta... 

use $sa/data/clus, clear

****************** 
* 	TABELLA 3
******************
tab1 oma* if time==1
tab oma7 if time==1


* Descrizione dei cluster  -- non riportato nel testo 
bys id: gen stat1=empstat if _n==1
replace stat1=stat1[_n-1] if id==id& _n!=1
egen dur11=sqlength(), element(11)	
egen dur12=sqlength(), element(12)
egen dur13=sqlength(), element(13)
egen dur20=sqlength(), element(20)
egen dur30=sqlength(), element(30)

egen elemnum = sqelemcount()         
egen chnum = sqepicount()            
egen epinum13 = sqepicount(), element(13) 

mean dur* elemnum chnum epinum13 , over(oma7), if time==1 
foreach m of numlist  1 2 3 4 5 6 7 {
	di in red "cluster==`m' "
	sqtab, so, if oma7==`m'
	}
	
*****************************
* 	TABELLA 4 + FIGURA 4 
*****************************
tab oma7 genere, col, if time==1
tab oma7 bcoho, col, if time==1
tab oma7 bcoho if time==1

lab def oma7 1"AUT" 2"DIP/INATT" 3"DIP_t.det-->indet" 4"DIP_t.det" ///
	5"DISOCC" 6"DIP_indet+INA/DIS" 7"DIP_indet", modify
lab val oma7 oma7 
catplot oma7, over(bcoho, label(labsize(*.7) angle(90)) gap(*.2)) percent(bcoho) stack  asyvars ///
	legend(region(lstyle(none) lcolor(gs14) fcolor(gs14)) row(2) stack keygap(*0.2) bmargin(tiny) size(*0.85) symysize(*0.5) symxsize(*1)) ///
	title("cluster per coorte", size(*.8) margin(zero)) b1title("") ///
   	ylabel(0(10)100, angle(0) axis(1)) ytitle("%", size(*.8) margin(zero)) ///
	ymtick(0(5)100) recast(bar) bar(1, bcolor(ltblue)) bar(2, bcolor(gs8)) bar(3, bcolor(yellow)) ///
	bar(4, bcolor(orange)) bar(5, bcolor(red)) bar(6, bcolor(lavender)) bar(7, bcolor(blue)) ///
	plotregion(margin(tiny)) graphregion(color(gs14)) name(SA_clusC, replace)

	

******************
* 	FIGURA 3
******************
* Attenzione: OVERPLOTTING !
help sqindexplot
/*
sqindexplot, order(oma7 stat1 oma15 ///
elemnum chnum dur13 dur20 dur12) overplot(1) ///
xtitle ("mesi") ytitle ("persone") xlabel(0(12)60) ///
color(ltblue blue orange red gs15) ///
yline(108 142 185 281 433 483 , lcolor(black) lwidth(thin)) ///
ylabel(0 100 to 864)
*/

* solo cluster 3 

sqindexplot, order(oma15 stat1)  rbar  ///
xtitle ("mesi") ytitle ("persone") xlabel(0(12)60) ///
color(ltblue blue orange red gs8) ///
ylabel(0 10 to 43) , if oma7==3, name(clus3, replace) 

* in bianco-nero
sqindexplot, order(oma15) rbar ///
xtitle ("mesi") ytitle ("persone") xlabel(0(12)60) ///
color(gs14 gs10 gs7 gs4 black ) ///
ylabel(0 10 to 43) , if oma7==3, name(clus3bw, replace) 

* solo cluster 4
sqindexplot, order(oma15)  overplot(70)  ///
xtitle ("mesi") ytitle ("persone") xlabel(0(12)60) ///
color(ltblue blue orange red gs8) /// 
ylabel(0 10 to 96) , if oma7==4, name(clus4, replace) 


* basato su un 30% subsample 
save $sa/clus_, replace
keep if time==1
bys oma6: sample 30
gen s30=1
keep id s30
sort id
save $sa/s30, replace
use $sa/clus_, clear
merge id using $sa/s30
drop _merge
tab s30, mis

keep if s30==1
tab oma7 if time==1

**************
* FIGURA 3
************** 

sqindexplot, order(oma7 stat1 oma15) rbar  ///
xtitle ("mesi") ytitle ("persone") xlabel(0(12)60) ///
color(ltblue blue orange red gs8) ///
yline(32 42 55 84 130 143 , lcolor(black) lwidth(thin)) ///
ylabel(0 25 to 259) name(clusall30pct, replace) 

sqindexplot, order(oma7 stat1 oma15) rbar ///
xtitle ("mesi") ytitle ("persone") xlabel(0(12)60) ///
color(gs14 gs10 gs7 gs4 black ) ///
yline(32 42 55 84 130 143, lcolor(black) lwidth(thick)) ///
ylabel(0 25 to 259) name(clusall30pct_bw, replace) 


* cancellare le cose inutili  
*erase "$sa/clus" 
erase "$sa/clus_.dta" 
erase "$sa/s30.dta" 

clear 

